==> haskell-path-io-1.3.3-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-path-io.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: path-io
version: 1.3.3
id: path-io-1.3.3-JjKgTqlR1xjEO4HrCq8LM8
key: path-io-1.3.3-JjKgTqlR1xjEO4HrCq8LM8
license: BSD3
maintainer: Mark Karpov <markkarpov92@gmail.com>
homepage: https://github.com/mrkkrp/path-io
synopsis: Interface to ‘directory’ package for users of ‘path’
description:
    Interface to ‘directory’ package for users of ‘path’.
category: System, Filesystem
author: Mark Karpov <markkarpov92@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Path.IO
abi: b0490e7a4565c64020ca555a42c8d717
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/path-io-1.3.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/path-io-1.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/path-io-1.3.3
hs-libraries: HSpath-io-1.3.3-JjKgTqlR1xjEO4HrCq8LM8
depends:
    base-4.10.0.0 containers-0.5.10.2 directory-1.3.0.2
    dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q
    exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6 filepath-1.4.1.2
    path-0.6.1-J2XKJSE31t8HObNnsS2t6I
    temporary-1.2.1.1-JiAl6vZksoXBKGEB3ysIBo time-1.8.0.2
    transformers-0.5.2.0 unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q=39b750082c56951484aa28fb24175e9c
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=e190029673d5410544b32623a0e81f5f
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             path-0.6.1-J2XKJSE31t8HObNnsS2t6I=34f78d95f83c0326c020a4a067c14526
             temporary-1.2.1.1-JiAl6vZksoXBKGEB3ysIBo=b2bbe16ff4ee22883b159097e4afbbd0
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp=de9563896484115ad3fe305bce9cecd3
haddock-interfaces: /usr/share/doc/haskell-path-io/html/path-io.haddock
haddock-html: /usr/share/doc/haskell-path-io/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-path-io-1.3.3-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-path-io.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: path-io
version: 1.3.3
id: path-io-1.3.3-CaMBTIAbjlFIASM7B7Lrep
key: path-io-1.3.3-CaMBTIAbjlFIASM7B7Lrep
license: BSD3
maintainer: Mark Karpov <markkarpov92@gmail.com>
homepage: https://github.com/mrkkrp/path-io
synopsis: Interface to ‘directory’ package for users of ‘path’
description:
    Interface to ‘directory’ package for users of ‘path’.
category: System, Filesystem
author: Mark Karpov <markkarpov92@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Path.IO
abi: 10ceefb2d41ccc44b2f655f22d25f01d
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/path-io-1.3.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/path-io-1.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/path-io-1.3.3
hs-libraries: HSpath-io-1.3.3-CaMBTIAbjlFIASM7B7Lrep
depends:
    base-4.10.0.0 containers-0.5.10.2 directory-1.3.0.2
    dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q
    exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6 filepath-1.4.1.2
    path-0.6.1-7YfFlFvX9AU7kgh9YHsqLC
    temporary-1.2.1.1-JiAl6vZksoXBKGEB3ysIBo time-1.8.0.2
    transformers-0.5.2.0 unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q=39b750082c56951484aa28fb24175e9c
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=e190029673d5410544b32623a0e81f5f
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             path-0.6.1-7YfFlFvX9AU7kgh9YHsqLC=250d37ad74db1f7b91e1f08a14e4d4ea
             temporary-1.2.1.1-JiAl6vZksoXBKGEB3ysIBo=b2bbe16ff4ee22883b159097e4afbbd0
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp=de9563896484115ad3fe305bce9cecd3
haddock-interfaces: /usr/share/doc/haskell-path-io/html/path-io.haddock
haddock-html: /usr/share/doc/haskell-path-io/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
